# Changelog

## 0.5.0 2023 Dec 1

- fix #1: use correct NotebookPanel instance

## 0.4.4 2023 Nov 26

- export md_toggle_multi
- re-release after several crippled attempts

## 0.3.1 2023 Jul 2

- initial release
- requires jlab4
